import Helper from '@ember/component/helper';
import { addListener, removeListener } from '@ember/object/events';

function _defineProperty(obj, key, value) {
  key = _toPropertyKey(key);
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}
function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];
  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (hint === "string" ? String : Number)(input);
}
function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");
  return typeof key === "symbol" ? key : String(key);
}

// We define these explicitly rather than using `Parameters<typeof addListener>`
// because `addListener`'s arguments were typed incorrectly in earlier preview
// versions of Ember types.
class AddListenerHelper extends Helper {
  constructor(...args) {
    super(...args);
    _defineProperty(this, "removeListener", void 0);
  }
  compute(args) {
    this.checkRemoveListener();
    const [obj, eventName, target, method, once] = args;
    // method and once are optional
    if (!obj || !eventName || !target) {
      return undefined;
    }
    addListener(obj, eventName, target, method, once);
    this.removeListener = () => removeListener(obj, eventName, target, method);
    return undefined;
  }
  willDestroy() {
    this.checkRemoveListener();
    super.willDestroy();
  }
  checkRemoveListener() {
    if (this.removeListener) {
      this.removeListener();
      delete this.removeListener;
    }
  }
}

export { AddListenerHelper as default };
//# sourceMappingURL=add-listener.js.map
